@@ -470,12 +470,16 @@ datetounix(long long year, int mon, int day, int hour, int min, int sec)
 		if (!rem) {
 			is_leap = 1;
 		} else {
-			if (rem >= 300)
-				centuries = 3, rem -= 300;
-			else if (rem >= 200)
-				centuries = 2, rem -= 200;
-			else if (rem >= 100)
-				centuries = 1, rem -= 100;
+			if (rem >= 300) {
+				centuries = 3;
+				rem -= 300;
+			} else if (rem >= 200) {
+				centuries = 2;
+				rem -= 200;
+			} else if (rem >= 100) {
+				centuries = 1;
+				rem -= 100;
+			}
 			if (rem) {
 				leaps = rem / 4U;
 				rem %= 4U;
@@ -500,10 +504,10 @@ datetounix(long long year, int mon, int day, int hour, int min, int sec)
 }
 
 /* Get timezone from string, return time offset in seconds from UTC.
- * NOTE: only parses timezones in RFC-822, many other timezone names are
+ * NOTE: only parses timezones in RFC 822, many other timezone names are
  * ambiguous anyway.
- * ANSI and military zones are defined wrong in RFC822 and are unsupported,
- * see note on RFC2822 4.3 page 32. */
+ * ANSI and military zones are defined wrong in RFC 822 and are unsupported,
+ * see note on RFC 2822 4.3 page 32. */
 static long
 gettzoffset(const char *s)
 {
@@ -623,7 +627,7 @@ parsetime(const char *s, long long *tp)
 			;
 		for (v = 0, i = 0; i < 4 && ISDIGIT((unsigned char)*s); s++, i++)
 			v = (v * 10) + (*s - '0');
-		/* obsolete short year: RFC2822 4.3 */
+		/* obsolete short year: RFC 2822 4.3 */
 		if (i == 2 || i == 3)
 			v += (i == 2 && v >= 0 && v <= 49) ? 2000 : 1900;
 		va[0] = v; /* year */
@@ -720,8 +724,8 @@ xmlattr(XMLParser *p, const char *t, size_t tl, const char *n, size_t nl,
 	if (!ctx.tag.id)
 		return;
 
-	/* content-type may be: Atom: text, xhtml, html or mime-type.
-	   MRSS (media:description): plain, html. */
+	/* content-type may be for Atom: text, xhtml, html or a mime-type.
+	   for MRSS (media:description): plain, html. */
 	if (ISCONTENTTAG(ctx)) {
 		if (isattr(n, nl, STRP("type")))
 			string_append(&attrtype, v, vl);
@@ -1069,7 +1073,7 @@ main(int argc, char *argv[])
 	parser.xmltagstart = xmltagstart;
 	parser.xmltagstartparsed = xmltagstartparsed;
 
-	/* NOTE: getnext is defined in xml.h for inline optimization */
+	/* NOTE: GETNEXT is defined in xml.h for inline optimization */
 	xml_parse(&parser);
 
 	checkfileerror(stdin, "<stdin>", 'r');
