@@ -11,7 +11,7 @@ static size_t linesize;
 static time_t comparetime;
 
 /* Escape characters in gopher, CR and LF are ignored */
-void
+static void
 gophertext(FILE *fp, const char *s)
 {
 	for (; *s; s++) {
@@ -118,7 +118,7 @@ printfeed(FILE *fpitems, FILE *fpin, struct feed *f)
 int
 main(int argc, char *argv[])
 {
-	struct feed f;
+	struct feed f = { 0 };
 	FILE *fpitems, *fpindex, *fp;
 	char *name, *p;
 	int i;
